@@ -1,6 +1,9 @@
 from muid.corpus import search
 from muid.crypto import bhash
 
+def difficulty(key):
+    return len(animal(key).replace(' ',''))
+
 def animal(key):
     bkey = key if isinstance(key,bytes) else key.encode('ascii')
     code = bhash(bkey)
